==> AsposeCellsCloud-CellsApi-25.6.1.tar.gz: AsposeCellsCloud-CellsApi-25.6.1/docs/model/Protection.md <==
# AsposeCellsCloud::Object::Protection 

## Load the model package
```perl
use AsposeCellsCloud::Object::Protection;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**AllowDeletingColumn** | **boolean** | Represents if the deletion of columns is allowed on a protected worksheet.  |
**AllowDeletingRow** | **boolean** | Represents if the deletion of rows is allowed on a protected worksheet.  |
**AllowFiltering** | **boolean** | Represents if the user is allowed to make use of an AutoFilter that was created before the sheet was protected.  |
**AllowFormattingCell** | **boolean** | Represents if the formatting of cells is allowed on a protected worksheet.  |
**AllowFormattingColumn** | **boolean** | Represents if the formatting of columns is allowed on a protected worksheet  |
**AllowFormattingRow** | **boolean** | Represents if the formatting of rows is allowed on a protected worksheet  |
**AllowInsertingColumn** | **boolean** | Represents if the insertion of columns is allowed on a protected worksheet  |
**AllowInsertingHyperlink** | **boolean** | Represents if the insertion of hyperlinks is allowed on a protected worksheet  |
**AllowInsertingRow** | **boolean** | Represents if the insertion of rows is allowed on a protected worksheet  |
**AllowSorting** | **boolean** | Represents if the sorting option is allowed on a protected worksheet.  |
**AllowUsingPivotTable** | **boolean** | Represents if the user is allowed to manipulate pivot tables on a protected worksheet.  |
**AllowEditingContent** | **boolean** | Represents if the user is allowed to edit contents of locked cells on a protected worksheet.  |
**AllowEditingObject** | **boolean** | Represents if the user is allowed to manipulate drawing objects on a protected worksheet.  |
**AllowEditingScenario** | **boolean** | Represents if the user is allowed to edit scenarios on a protected worksheet.  |
**Password** | **string** | Represents the password to protect the worksheet.  |
**AllowSelectingLockedCell** | **boolean** | Represents if the user is allowed to select locked cells on a protected worksheet.  |
**AllowSelectingUnlockedCell** | **boolean** | Represents if the user is allowed to select unlocked cells on a protected worksheet.  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/Protection.md <==
# AsposeCellsCloud::Object::Protection 

## Load the model package
```perl
use AsposeCellsCloud::Object::Protection;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**AllowDeletingColumn** | **boolean** | Represents if the deletion of columns is allowed on a protected worksheet.  |
**AllowDeletingRow** | **boolean** | Represents if the deletion of rows is allowed on a protected worksheet.  |
**AllowFiltering** | **boolean** | Represents if the user is allowed to make use of an AutoFilter that was created before the sheet was protected.  |
**AllowFormattingCell** | **boolean** | Represents if the formatting of cells is allowed on a protected worksheet.  |
**AllowFormattingColumn** | **boolean** | Represents if the formatting of columns is allowed on a protected worksheet  |
**AllowFormattingRow** | **boolean** | Represents if the formatting of rows is allowed on a protected worksheet  |
**AllowInsertingColumn** | **boolean** | Represents if the insertion of columns is allowed on a protected worksheet  |
**AllowInsertingHyperlink** | **boolean** | Represents if the insertion of hyperlinks is allowed on a protected worksheet  |
**AllowInsertingRow** | **boolean** | Represents if the insertion of rows is allowed on a protected worksheet  |
**AllowSorting** | **boolean** | Represents if the sorting option is allowed on a protected worksheet.  |
**AllowUsingPivotTable** | **boolean** | Represents if the user is allowed to manipulate pivot tables on a protected worksheet.  |
**AllowEditingContent** | **boolean** | Represents if the user is allowed to edit contents of locked cells on a protected worksheet.  |
**AllowEditingObject** | **boolean** | Represents if the user is allowed to manipulate drawing objects on a protected worksheet.  |
**AllowEditingScenario** | **boolean** | Represents if the user is allowed to edit scenarios on a protected worksheet.  |
**Password** | **string** | Represents the password to protect the worksheet.  |
**AllowSelectingLockedCell** | **boolean** | Represents if the user is allowed to select locked cells on a protected worksheet.  |
**AllowSelectingUnlockedCell** | **boolean** | Represents if the user is allowed to select unlocked cells on a protected worksheet.  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
